translate.storage.placeables.interfaces.Delimiter

Package translate :: Package storage :: Package placeables :: Module interfaces :: Class Delimiter |
[hide private]
[frames] | no frames]

# Class Delimiter

source code

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`